package io.github.wulkanowy.ui.modules.settings.mod_settings

import io.github.wulkanowy.data.repositories.PreferencesRepository
import io.github.wulkanowy.data.repositories.StudentRepository
import io.github.wulkanowy.ui.base.BasePresenter
import io.github.wulkanowy.ui.base.ErrorHandler
import io.github.wulkanowy.ui.modules.dashboard.DashboardItem
import io.github.wulkanowy.utils.AnalyticsHelper
import timber.log.Timber
import javax.inject.Inject

class ModSettingsPresenter @Inject constructor(
    errorHandler: ErrorHandler,
    studentRepository: StudentRepository,
    private val analytics: AnalyticsHelper,
    private val preferencesRepository: PreferencesRepository
) : BasePresenter<ModSettingsView>(errorHandler, studentRepository) {

    override fun onAttachView(view: ModSettingsView) {
        super.onAttachView(view)

        Timber.i("Mod settings view was initialized")
    }

    fun onSharedPreferenceChanged(key: String?) {
        key ?: return
        Timber.i("Change mod settings $key")
        analytics.logEvent("setting_changed", "name" to key)
    }

    fun onHiddenGradesSelected(selectedItems: List<String>) {
        preferencesRepository.hiddenGrades = selectedItems
        view?.restartApp()
    }

    fun onAttendanceSettingsSelected(selectedValues: List<DashboardItem.HiddenAttendanceTile>) {
        preferencesRepository.hiddenAttendanceItems = selectedValues
        view?.restartApp()
    }
}
